@@ -23,13 +23,20 @@
 #' @param count \code{logical} to include count and total in the explanation.
 #' @param explanation JavaScript function to define a custom explanation for the center
 #'          of the sunburst.  Note, this will override \code{percent} and \code{count}.
-#' @param breadcrumb,legend \code{list} to customize the breadcrumb trail or legend.  This argument
+#' @param breadcrumb \code{list} to customize the breadcrumb trail.  This argument
 #'          should be in the form \code{list(w =, h =, s =, t = )} where
 #'          \code{w} is the width, \code{h} is the height, \code{s} is the spacing,
 #'          and \code{t} is the tail all in \code{px}. \code{w} is \code{0} by default for
 #'          breadcrumbs widths based on text length.
+#' @param legend \code{list} to customize the legend or \code{logical} to disable the legend.  The \code{list} argument
+#'          should be in the form \code{list(w =, h =, r =, s = )} where
+#'          \code{w} is the width, \code{h} is the height, \code{s} is the spacing,
+#'          and \code{r} is the radius all in \code{px}.
 #' @param sortFunction \code{\link[htmlwidgets]{JS}} function to sort the slices.
 #'          The default sort is by size.
+#' @param sumNodes \code{logical} to sum non-leaf nodes.  The default
+#'          \code{sumNodes = TRUE} assumes that the user has not already
+#'          calculated a sum.
 #' @param withD3 \code{logical} to include d3 dependency from \code{d3r}.  As of
 #'          version 1.0, sunburst uses a standalone JavaScript build and will
 #'          not include the entire d3 in the global/window namespace.  To include
@@ -61,6 +68,7 @@ sunburst <- function(
   , breadcrumb = list()
   , legend = list()
   , sortFunction = NULL
+  , sumNodes = TRUE
   , withD3 = FALSE
   , width = NULL
   , height = NULL
@@ -118,6 +126,7 @@ sunburst <- function(
       ,breadcrumb = breadcrumb
       ,legend = legend
       ,sortFunction = sortFunction
+      ,sumNodes = sumNodes
     )
   )
 
@@ -188,7 +197,12 @@ sunburst_html <- function(id, style, class, ...){
           )
         )
         ,tags$div(class = "sunburst-sidebar"
-          , tags$input( type = "checkbox", class = "sunburst-togglelegend", "Legend" )
+          , tags$input(
+            type = "checkbox",
+            class = "sunburst-togglelegend",
+            style = "visibility:hidden;",
+            "Legend"
+          )
           , tags$div( class = "sunburst-legend", style = "visibility:hidden;" )
         )
       )
